richardview.majumdar\_lab\_widgets.aalborg\_dpc\_widget module
==============================================================

.. automodule:: richardview.majumdar_lab_widgets.aalborg_dpc_widget
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
